package tokyo.swet.uitest;

import android.support.test.runner.AndroidJUnit4;
import android.view.View;
import android.widget.ListView;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import tokyo.swet.uitest.helper.ActivityTestBase;

import static android.support.test.espresso.matcher.ViewMatchers.assertThat;
import static android.support.test.espresso.matcher.ViewMatchers.withText;
import static tokyo.swet.uitest.helper.ListViewHelper.findFirstChild;
import static tokyo.swet.uitest.helper.NoteHelper.createNote;
import static tokyo.swet.uitest.helper.NoteHelper.randomContent;
import static tokyo.swet.uitest.helper.NoteHelper.randomTitle;
import static tokyo.swet.uitest.helper.UserHelper.loginAsRegisteredUser;
import static tokyo.swet.uitest.helper.ViewHelper.selectTab;
import static tokyo.swet.uitest.matcher.UITestViewMatcher.hasErrorTextInLayout;

/**
 * ノート機能（ログイン状態）に関するテスト
 * Created by SWET.
 */
@RunWith(AndroidJUnit4.class)
public class NoteLoginStateTests extends ActivityTestBase {

    @Before
    public void setUp() {
        loginAsRegisteredUser();
        selectTab(withText(R.string.tab_note));
    }

    @Test
    public void createNewNote() {
        // 任意のタイトルと内容を入力する
        String title   = randomTitle();
        String content = randomContent();
        createNote(title, content);

        // 登録したタイトルが表示されていることを確認
        ListView notes = (ListView) activity.findViewById(R.id.notes_list_title);
        assertThat(
                title + "がListViewに表示されている",
                findFirstChild(notes),
                withText(title)
        );
    }

    @Test
    public void createNoteWithEmptyTitle() {
        // 内容のみを空にし、タイトルには値を入力
        String title = randomTitle();
        createNote(title, "");

        // 登録したタイトルが表示されていることを確認
        ListView notes = (ListView) activity.findViewById(R.id.notes_list_title);
        assertThat(
                title + "がListViewに表示されている",
                findFirstChild(notes),
                withText(title)
        );
    }

    @Test
    public void createNoteWithEmptyContent() {
        // タイトルのみ空にする
        createNote("", randomContent());

        //エラー文言が正しく表示されていることを確認
        String expectMessage = messageHelper.geLocalizedMessage(R.string.error_required);
        View noteTitle = activity.findViewById(R.id.note_inputLayout_title);
        assertThat(
                "正しいメッセージが表示されている",
                noteTitle,
                hasErrorTextInLayout(expectMessage)
        );
    }
}
