package tokyo.swet.uitest;

import android.support.test.runner.AndroidJUnit4;

import org.junit.Before;
import org.junit.Test;
import org.junit.runner.RunWith;

import tokyo.swet.uitest.helper.ActivityTestBase;

import static android.support.test.espresso.matcher.ViewMatchers.assertThat;
import static android.support.test.espresso.matcher.ViewMatchers.isDisplayed;
import static android.support.test.espresso.matcher.ViewMatchers.withText;
import static tokyo.swet.uitest.helper.AssetHelper.testUser;
import static tokyo.swet.uitest.helper.UserHelper.login;
import static tokyo.swet.uitest.helper.UserHelper.loginAsRegisteredUser;
import static tokyo.swet.uitest.helper.UserHelper.logout;
import static tokyo.swet.uitest.helper.ViewHelper.waitUntilTextDisplayed;

/**
 * ログインに関するテスト
 * Created by SWET.
 */
@RunWith(AndroidJUnit4.class)
public class UserLoginTests extends ActivityTestBase {

    @Before
    public void setup() {
        logout();
    }

    @Test
    public void loginRegisteredAccount() {
        // 登録済みユーザでログイン
        loginAsRegisteredUser();

        // 登録したニックネームと
        // メールアドレスが表示されていることの確認
        assertThat(
                "登録したニックネームが表示されている",
                activity.findViewById(R.id.auth_label_nickname),
                withText(testUser().getNickname())
        );
        assertThat(
                "登録したメールアドレスが表示されている",
                activity.findViewById(R.id.auth_label_email),
                withText(testUser().getEmail())
        );

        // ログアウトボタンが表示されていることの確認
        assertThat(
                "ログアウトボタンが表示されている",
                activity.findViewById(R.id.auth_button_logout),
                isDisplayed()
        );
    }

    @Test
    public void loginWithInvalidPassword() {
        // 存在するユーザーの
        // メールアドレスと不適切なパスワードを入力
        login(testUser().getEmail(), "invalid_password");

        // エラーメッセージが表示されるまで待つ
        waitUntilTextDisplayed(R.id.auth_label_loginErrors);

        // エラーメッセージが表示されていることの確認
        String expectMessage = messageHelper.geLocalizedMessage(R.string.failed_login);
        assertThat(
                "正しいメッセージが表示されていること",
                activity.findViewById(R.id.auth_label_loginErrors),
                withText(expectMessage)
        );
    }
}
