package tokyo.swet.uitest.helper;

import android.support.test.espresso.NoMatchingViewException;

import junit.framework.AssertionFailedError;

import tokyo.swet.uitest.R;
import tokyo.swet.uitest.model.User;

import static android.support.test.espresso.Espresso.onView;
import static android.support.test.espresso.action.ViewActions.click;
import static android.support.test.espresso.action.ViewActions.replaceText;
import static android.support.test.espresso.action.ViewActions.scrollTo;
import static android.support.test.espresso.assertion.ViewAssertions.matches;
import static android.support.test.espresso.matcher.ViewMatchers.isDisplayed;
import static android.support.test.espresso.matcher.ViewMatchers.withId;
import static android.support.test.espresso.matcher.ViewMatchers.withText;
import static org.apache.commons.lang3.RandomStringUtils.random;
import static org.apache.commons.lang3.RandomStringUtils.randomAlphabetic;
import static tokyo.swet.uitest.helper.AssetHelper.testUser;
import static tokyo.swet.uitest.helper.ViewHelper.selectTab;
import static tokyo.swet.uitest.helper.ViewHelper.waitUntilDisplayed;

/**
 * Created by SWET.
 */

public class UserHelper {

    /**
     * ユニークなニックネームを取得します
     * @return ニックネーム文字列
     */
    public static String temporaryNickname() {
        return "SWET" + random(3, 'あ', 'ん', false, false) + System.currentTimeMillis();
    }

    /**
     * ユニークなメールアドレスを取得します
     * @return メールアドレス文字列
     */
    public static String temporaryMailAddress() {
        return randomAlphabetic(10).toLowerCase() + System.currentTimeMillis() + "@example.com";
    }

    /**
     * ランダムなパスワードを取得します
     * @return パスワード文字列
     */
    public static String temporaryPassword() {
        return "password." + randomAlphabetic(4) + System.currentTimeMillis();
    }

    /**
     * メールアドレスとパスワードを指定してログインを試みます
     *
     * @param email メールアドレス
     * @param password パスワード
     */
    public static void login(String email, String password) {
        selectTab(withText(R.string.tab_user));

        // 値を入力する
        onView(withId(R.id.auth_input_loginEmail)).perform(replaceText((email)));
        onView(withId(R.id.auth_input_loginPassword)).perform(replaceText(password));

        // ログインボタンをクリックする
        onView(withId(R.id.auth_button_login)).perform(scrollTo(), click());
    }

    /**
     * テストユーザでログインします
     */
    public static void loginAsRegisteredUser() {
        logout();

        User testUser = testUser();
        login(testUser.getEmail(), testUser.getPassword());

        waitUntilDisplayed(R.id.auth_label_nickname);
    }

    /**
     * ログアウトします
     */
    public static void logout() {
        selectTab(withText(R.string.tab_user));
        try {
            onView(withId(R.id.auth_button_logout)).check(matches(isDisplayed())).perform(click());
        } catch (NoMatchingViewException | AssertionFailedError ignore) {
        }
    }

    /**
     * 指定された値でユーザ登録します
     * @param nickname ニックネーム
     * @param email メールアドレス
     * @param password パスワード
     */
    public static void registerUser(String nickname, String email, String password) {
        selectTab(withText(R.string.tab_user));

        // 値を入力する
        onView(withId(R.id.auth_input_registerNickname)).perform(replaceText(nickname));
        onView(withId(R.id.auth_input_registerEmail)).perform(replaceText(email));
        onView(withId(R.id.auth_input_registerPassword)).perform(replaceText(password));

        // 登録ボタンをクリックする
        onView(withId(R.id.auth_button_register)).perform(scrollTo(), click());
    }
}
