package tokyo.swet.uitest;

import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentPagerAdapter;
import android.support.v4.content.ContextCompat;
import android.support.v4.view.PagerTabStrip;
import android.support.v4.view.ViewPager;

public class MainActivity extends FragmentActivity {

    public enum Page {

        USER(0), NOTE(1);

        private final int index;

        public int getIndex() {
            return index;
        }

        Page(int index) {
            this.index = index;
        }
    }

    private FragmentPagerAdapter mFragmentPagerAdapter;
    private ViewPager mViewPager;

    public static final int[] pageTitles = {
            R.string.tab_user,
            R.string.tab_note,
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        createViewPager();
    }

    private void createViewPager() {

        mViewPager = (ViewPager) findViewById(R.id.pager);
        PagerTabStrip pagerTabStrip = (PagerTabStrip) findViewById(R.id.pager_tab_strip);

        mFragmentPagerAdapter = new MyFragmentPagerAdapter(this, getSupportFragmentManager());

        mViewPager.setAdapter(mFragmentPagerAdapter);
        mViewPager.setOffscreenPageLimit(getPageCount());

        pagerTabStrip.setDrawFullUnderline(true);
        pagerTabStrip.setTabIndicatorColor(ContextCompat.getColor(this, R.color.cyan));
        pagerTabStrip.setBackgroundColor(ContextCompat.getColor(this, R.color.black));
    }

    public int getPageCount() {
        return pageTitles.length;
    }

    public String getPageTitle(int index) {
        return getResources().getString(pageTitles[index]);
    }

    public void changePage(Page page) {
        mViewPager.setCurrentItem(page.getIndex());
        mFragmentPagerAdapter.notifyDataSetChanged();
    }
}
