//
//  Copyright (c) 2017 SWET. All rights reserved.
//

import Foundation
import XCTest

fileprivate let app = XCUIApplication()

/// XCTestにおいて要素にシンプルにアクセスするためのプロトコル拡張です
protocol ElementAccessor {
    static var prefix: String { get }
}

extension ElementAccessor {
    
    /// `prefix`と組み合わせたID文字列を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: ID文字列
    static func id(_ identifier: String) -> String {
        return Self.prefix + identifier
    }
    
    /// ボタン要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: ボタン
    static func button(_ identifier: String) -> XCUIElement {
        return app.buttons[Self.id(identifier)]
    }
    
    /// テキストフィールド要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: テキストフィールド
    static func textField(_ identifier: String) -> XCUIElement {
        return app.textFields[Self.id(identifier)]
    }
    
    /// パスワード用のテキストフィールド要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: テキストフィールド
    static func secureTextFields(_ identifier: String) -> XCUIElement {
        return app.secureTextFields[Self.id(identifier)]
    }
    
    /// テキストビュー要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: テキストビュー
    static func textView(_ identifier: String) -> XCUIElement {
        return app.textViews[Self.id(identifier)]
    }
    
    /// ラベル要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: ラベル
    static func staticText(_ identifier: String) -> XCUIElement {
        return app.staticTexts[Self.id(identifier)]
    }

    /// テーブル要素を取得します
    ///
    /// - Parameter identifier: 要素のID
    /// - Returns: ラベル
    static func tableView(_ identifier: String) -> XCUIElement {
        return app.tables[self.id(identifier)]
    }

}
