//
//  Copyright (c) 2017 SWET. All rights reserved.
//

import Foundation
import XCTest

private let DEFAULT_TIMEOUT_SECOND: TimeInterval = 10

extension XCTestCase {
    
    /// 要素が表示されるまで待ちます
    ///
    /// - Parameters:
    ///   - evaluatedObject: 要素
    ///   - seconds: 最大待ち時間(秒)
    func waitExists(for evaluatedObject: Any, timeout seconds: TimeInterval = DEFAULT_TIMEOUT_SECOND) {
        
        let predicate = NSPredicate(format: "exists == true")
        let exp = expectation(for: predicate, evaluatedWith: evaluatedObject)
        
        wait(for: [exp], timeout: seconds)
    }
    
    /// 要素がタップされる状態になるまで待ちます
    ///
    /// - Parameters:
    ///   - evaluatedObject: 要素
    ///   - seconds: 最大待ち時間(秒)
    func waitHittable(for evaluatedObject: Any, timeout seconds: TimeInterval = DEFAULT_TIMEOUT_SECOND) {
        
        let predicate = NSPredicate(format: "isHittable == true")
        let exp = expectation(for: predicate, evaluatedWith: evaluatedObject)
        
        wait(for: [exp], timeout: seconds)
    }

}
