//
//  Copyright (c) 2017 SWET. All rights reserved.
//

import Foundation
import XCTest

extension XCTestCase {

    func selectTab(_ tab: Tab) {
        XCUIApplication().staticTexts[tab.title].tap()
    }

    /// ユーザー登録をします
    ///
    /// - Parameter nickname: ニックネーム
    /// - Parameter email: メールアドレス
    /// - Parameter password: パスワード
    func registerUser(nickname: String, email: String, password: String) {
        selectTab(.user)

        Login.registerButton.tap()

        UserRegister.nicknameText.inputText(nickname)
        UserRegister.emailText.inputText(email)
        UserRegister.passwordText.inputText(password)

        //登録ボタンをクリックする
        UserRegister.registerButton.tap()
    }

    /// テストユーザでログインします
    func loginAsRegisteredUser() {
        logout()

        let user = Assets.registeredUser
        login(email: user.email, password: user.password)
        waitHittable(for: UserStatus.logoutButton)
    }

    /// 指定されたemail、passwordでログインします
    ///
    /// - Parameter email: メールアドレス
    /// - Parameter password: パスワード
    func login(email: String, password: String) {
        selectTab(.user)
        
        // Note:
        // 実機では`isHittable`の判定だけで十分だが、シミュレータでは`exists`を先に判定する必要あり
        if Login.loginButton.exists && Login.loginButton.isHittable {
            
            Login.emailText.inputText(email)
            Login.passwordText.inputText(password)
            
            Login.loginButton.tap()
        }
    }
    
    /// ログアウトします
    func logout() {
        selectTab(.user)

        // Note:
        // 実機では`isHittable`の判定だけで十分だが、シミュレータでは`exists`を先に判定する必要あり
        if UserStatus.logoutButton.exists && UserStatus.logoutButton.isHittable {
            UserStatus.logoutButton.tap()
            waitHittable(for: Login.loginButton)
        }
    }

    /// 指定されたtitle、contentでノートを登録します
    ///
    /// - Parameter title: タイトル
    /// - Parameter content: 内容
    func createNote(title: String, content: String) {
        selectTab(.note)

        //ノート作成ボタンをクリック
        Note.createButton.tap()

        //保存ボタンが表示されるまで最大10秒待つ
        waitHittable(for: Note.saveButton)

        //登録フォームを空にする
        Note.clearButton.tap()

        //タイトルと内容を入力する
        Note.titleText.inputText(title)
        Note.contentTextView.inputText(content)

        //保存ボタンをクリック
        Note.saveButton.tap()
    }
}
