//
// Copyright (c) 2017 swet. All rights reserved.
//

import XCTest

/// ノート機能（ログイン状態）のテスト
class NoteLoginStateTests: XCTestCase {

    let app = XCUIApplication()

    override func setUp() {
        super.setUp()
        continueAfterFailure = false
        app.launch()

        loginAsRegisteredUser()
        selectTab(.note)
    }

    override func tearDown() {
        super.tearDown()
    }

    func testCreateNote() {
        // 任意のタイトルと内容を入力する
        let title = randomTitle()
        let content = randomContent()
        createNote(title: title, content: content)

        // 登録したタイトルが表示されていることを確認
        XCTAssertTrue(app.cells.staticTexts[title].exists, "\(title)がTableViewに表示されている")
    }

    func testCreateNoteWithEmptyContent() {
        // 内容のみを空にし、タイトルには値を入力
        let title = randomTitle()
        createNote(title: title, content: "")

        // 登録したタイトルが表示されていることを確認
        XCTAssertTrue(app.cells.staticTexts[title].exists, "\(title)がTableViewに表示されている")
    }

    func testCreateNoteWithEmptyTitle() {
        // タイトルのみ空で登録する
        createNote(title: "", content: randomContent())

        // エラー文言が正しく表示されていることを確認
        let expectMessage = Localized().string(forKey: "error_required")
        XCTAssertEqual(Note.titleErrorLabel.label, expectMessage, "正しいメッセージが表示されている")
    }
}
